==> zio-aws-route53recoverycontrolconfig_3-5.17.269.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/AssertionRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class AssertionRule(
    assertedControls: Iterable[__stringMin1Max256PatternAZaZ09],
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    safetyRuleArn: __stringMin1Max256PatternAZaZ09,
    status: zio.aws.route53recoverycontrolconfig.model.Status,
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule = {
    import AssertionRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
      .builder()
      .assertedControls(assertedControls.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .controlPanelArn(controlPanelArn: java.lang.String)
      .name(name: java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .safetyRuleArn(safetyRuleArn: java.lang.String)
      .status(status.unwrap)
      .waitPeriodMs(waitPeriodMs: Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.AssertionRule
      .wrap(buildAwsValue())
}
object AssertionRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.AssertionRule =
      zio.aws.route53recoverycontrolconfig.model.AssertionRule(
        assertedControls,
        controlPanelArn,
        name,
        ruleConfig.asEditable,
        safetyRuleArn,
        status,
        waitPeriodMs
      )
    def assertedControls: List[__stringMin1Max256PatternAZaZ09]
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def safetyRuleArn: __stringMin1Max256PatternAZaZ09
    def status: zio.aws.route53recoverycontrolconfig.model.Status
    def waitPeriodMs: __integer
    def getAssertedControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(assertedControls)
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getSafetyRuleArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(safetyRuleArn)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.route53recoverycontrolconfig.model.Status] =
      ZIO.succeed(status)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
  ) extends zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly {
    override val assertedControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .assertedControls()
      .asScala
      .map { item =>
        item: __stringMin1Max256PatternAZaZ09
      }
      .toList
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      impl.controlPanelArn(): __stringMin1Max256PatternAZaZ09
    override val name: __stringMin1Max64PatternS =
      impl.name(): __stringMin1Max64PatternS
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val safetyRuleArn: __stringMin1Max256PatternAZaZ09 =
      impl.safetyRuleArn(): __stringMin1Max256PatternAZaZ09
    override val status: zio.aws.route53recoverycontrolconfig.model.Status =
      zio.aws.route53recoverycontrolconfig.model.Status.wrap(impl.status())
    override val waitPeriodMs: __integer = impl.waitPeriodMs(): __integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
  ): zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-7.21.15.10-sources.jar: zio/aws/route53recoverycontrolconfig/model/AssertionRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __stringMin12Max12PatternD12,
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class AssertionRule(
    assertedControls: Iterable[__stringMin1Max256PatternAZaZ09],
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    safetyRuleArn: __stringMin1Max256PatternAZaZ09,
    status: zio.aws.route53recoverycontrolconfig.model.Status,
    waitPeriodMs: __integer,
    owner: Optional[__stringMin12Max12PatternD12] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule = {
    import AssertionRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
      .builder()
      .assertedControls(assertedControls.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .controlPanelArn(controlPanelArn: java.lang.String)
      .name(name: java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .safetyRuleArn(safetyRuleArn: java.lang.String)
      .status(status.unwrap)
      .waitPeriodMs(waitPeriodMs: Integer)
      .optionallyWith(owner.map(value => value: java.lang.String))(_.owner)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.AssertionRule
      .wrap(buildAwsValue())
}
object AssertionRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.AssertionRule =
      zio.aws.route53recoverycontrolconfig.model.AssertionRule(
        assertedControls,
        controlPanelArn,
        name,
        ruleConfig.asEditable,
        safetyRuleArn,
        status,
        waitPeriodMs,
        owner.map(value => value)
      )
    def assertedControls: List[__stringMin1Max256PatternAZaZ09]
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def safetyRuleArn: __stringMin1Max256PatternAZaZ09
    def status: zio.aws.route53recoverycontrolconfig.model.Status
    def waitPeriodMs: __integer
    def owner: Optional[__stringMin12Max12PatternD12]
    def getAssertedControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(assertedControls)
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getSafetyRuleArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(safetyRuleArn)
    def getStatus
        : ZIO[Any, Nothing, zio.aws.route53recoverycontrolconfig.model.Status] =
      ZIO.succeed(status)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
    def getOwner: ZIO[Any, AwsError, __stringMin12Max12PatternD12] =
      AwsError.unwrapOptionField("owner", owner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
  ) extends zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly {
    override val assertedControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .assertedControls()
      .asScala
      .map { item =>
        item: __stringMin1Max256PatternAZaZ09
      }
      .toList
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      impl.controlPanelArn(): __stringMin1Max256PatternAZaZ09
    override val name: __stringMin1Max64PatternS =
      impl.name(): __stringMin1Max64PatternS
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val safetyRuleArn: __stringMin1Max256PatternAZaZ09 =
      impl.safetyRuleArn(): __stringMin1Max256PatternAZaZ09
    override val status: zio.aws.route53recoverycontrolconfig.model.Status =
      zio.aws.route53recoverycontrolconfig.model.Status.wrap(impl.status())
    override val waitPeriodMs: __integer = impl.waitPeriodMs(): __integer
    override val owner: Optional[__stringMin12Max12PatternD12] =
      zio.aws.core.internal
        .optionalFromNullable(impl.owner())
        .map(value => value: __stringMin12Max12PatternD12)
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.AssertionRule
  ): zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly =
    new Wrapper(impl)
}
